@@ -299,6 +299,31 @@ class AcquisitionSearch:
         currently_acquiring = cls.acquiring_instance()
         return currently_acquiring.current_number, currently_acquiring.current_file
 
+    @classmethod
+    def wait_for_acquiring(cls,
+                           timeout: float = None,
+                           cycle_time: float = 0.1,
+                           ) -> Union['AcquisitionSearch', None]:
+        """
+        Waits for the acquiring flag file to appear in registered instances. Once found, the acquiring instance is
+        returned.
+
+        :param timeout: Optional timeout to prevent eternal waits
+        :param cycle_time: cycle time for checks
+        :return: acquiring instance once located
+        """
+        logger.info(f'waiting for ChemStation acquisition flag file {f"timeout: {timeout} s" if timeout else ""}')
+        if timeout is not None:
+            timeout = time.time() + timeout
+        # wait for appearance of file
+        while cls._located.is_set() is False:
+            if timeout and time.time() > timeout:
+                logger.info('timeout reached, no acquiring flag file was identified')
+                return  # return None if timeout is reached
+            time.sleep(cycle_time)
+        logger.info(f'acquiring instance located')
+        return cls.acquiring_instance()
+
 
 class ChemStationConfig:
     registered_chemstations: List['ChemStationConfig'] = []
@@ -431,7 +456,7 @@ class ChemStationConfig:
         :param env_name: environment variable name
         """
         path = os.environ.get(env_name)
-        if env_name is not None:
+        if path is not None:
             try:
                 return cls.get_by_data_path(path)
             except ValueError:
